package cn.bunny.services.service.financial;

import cn.bunny.dao.dto.financial.bill.admin.BillAddDto;
import cn.bunny.dao.dto.financial.bill.admin.BillDto;
import cn.bunny.dao.dto.financial.bill.admin.BillUpdateDto;
import cn.bunny.dao.dto.financial.bill.user.BillUserAddDto;
import cn.bunny.dao.dto.financial.bill.user.BillUserDto;
import cn.bunny.dao.dto.financial.bill.user.BillUserUpdateDto;
import cn.bunny.dao.entity.financial.Bill;
import cn.bunny.dao.pojo.result.PageResult;
import cn.bunny.dao.vo.financial.admin.BillVo;
import cn.bunny.dao.vo.financial.user.BillUserVo;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import jakarta.validation.Valid;

import java.util.List;

/**
 * <p>
 * 账单信息 服务类
 * </p>
 *
 * @author Bunny
 * @since 2024-11-07 16:49:19
 */
public interface BillService extends IService<Bill> {

    /**
     * * 获取账单信息列表
     *
     * @return 账单信息返回列表
     */
    PageResult<BillUserVo> getUserBillList(Page<Bill> pageParams, BillUserDto dto);

    /**
     * * 添加账单信息
     *
     * @param dto 添加表单
     */
    void addUserBill(@Valid BillUserAddDto dto);

    /**
     * * 更新账单信息
     *
     * @param dto 更新表单
     */
    void updateUserBill(@Valid BillUserUpdateDto dto);

    /**
     * * 删除|批量删除账单信息类型
     *
     * @param ids 删除id列表
     */
    void deleteUserBill(List<Long> ids);

    /**
     * 分页查询账单信息
     *
     * @return 账单信息返回列表
     */
    PageResult<BillVo> getBillList(Page<Bill> pageParams, BillDto dto);

    /**
     * 添加账单信息
     *
     * @param dto 添加表单
     */
    void addBill(BillAddDto dto);

    /**
     * 更新账单信息
     *
     * @param dto 更新表单
     */
    void updateBill(BillUpdateDto dto);

    /**
     * 删除账单信息
     *
     * @param ids 删除的ids
     */
    void deleteBill(List<Long> ids);
}
